@@ -58,7 +58,7 @@ function add_rslist ($post)
     global $log_msg;
     global $web_conf;
 
-    $vsiport    = $post["ipaddress"]."_".$post["port"];
+    $vsiport    = $post["ipaddress"]."_".$post["port"]."_".$post["protocol"];
     $rsiport    = $post["rs_ipaddress"]."_".$post["rs_port"];
     $rsconffile = $web_conf["iluka"]["keepalivedbasedir"]."virtual_server/$vsiport/real_server.conf";
 
@@ -163,6 +163,7 @@ function rs_hold_tag ($post)
 
     $tag["<<IPADDRESS>>"]               = escape_html($post["ipaddress"]);
     $tag["<<PORT>>"]                    = escape_html($post["port"]);
+    $tag["<<PROTOCOL>>"]                = escape_html($post["protocol"]);
     $tag["<<RS_IPADDRESS>>"]            = escape_html($post["rs_ipaddress"]);
     $tag["<<RS_PORT>>"]                 = escape_html($post["rs_port"]);
     $tag["<<WEIGHTING>>"]               = escape_html($post["weighting"]);
@@ -250,6 +251,8 @@ function rs_hold_tag ($post)
 /***********************************************************
  * 
  **********************************************************/
+$protocol_name = array("tcp", "udp");
+
 /* ե롢ִեɹåå */
 $ret = init();
 if ($ret === FALSE) {
@@ -311,7 +314,8 @@ if (isset($_POST["update"])) {
             $sesskey = $_POST["sk"];
             $msg = "ꥢ륵 ".$_POST["rs_ipaddress"]." ".$_POST["rs_port"]." ɲäޤ";
             $post = array("ipaddress" => $_POST["ipaddress"],
-                          "port"      => $_POST["port"]);
+                          "port"      => $_POST["port"],
+                          "protocol"  => $_POST["protocol"]);
             iluka_location("rslist.php", $msg, $post);
             exit(0);
         }
@@ -325,7 +329,8 @@ if (isset($_POST["update"])) {
     $sesskey = $_POST["sk"];
     $msg = "";
     $post = array("ipaddress" => $_POST["ipaddress"],
-                  "port"      => $_POST["port"]);
+                  "port"      => $_POST["port"],
+                  "protocol"  => $_POST["protocol"]);
     iluka_location("rslist.php", $msg, $post);
     exit(0);
 
@@ -334,6 +339,8 @@ if (isset($_POST["update"])) {
 
     $tag["<<IPADDRESS>>"] = $_POST["ipaddress"];
     $tag["<<PORT>>"]      = $_POST["port"];
+    $tag["<<PROTOCOL>>"]  = $_POST["protocol"];
+    $tag["<<PROTOCOL_NAME>>"] = $protocol_name[$_POST["protocol"]];
 
     $tag["<<RS_IPADDRESS>>"]            = "";
     $tag["<<RS_PORT>>"]                 = "";
