@@ -102,9 +102,12 @@ function conf_rsfile ($post,$vsiport, $rsiport)
 function change_tag_rsconf ($data)
 {
     global $health_check;
+    global $protocol_name;
 
     $tag["<<IPADDRESS>>"]          = escape_html($data["ipaddress"]);
     $tag["<<PORT>>"]               = escape_html($data["port"]);
+    $tag["<<PROTOCOL>>"]           = escape_html($data["protocol"]);
+    $tag["<<PROTOCOL_NAME>>"]      = escape_html($protocol_name[$data["protocol"]]);
     $tag["<<RSIPADDRESS>>"]        = escape_html($data["rs_ipaddress"]);
     $tag["<<RSPORT>>"]             = escape_html($data["rs_port"]);
     $tag["<<WEIGHT>>"]             = escape_html($data["weight"]);
@@ -170,9 +173,12 @@ function change_tag_rsconf ($data)
 function rsconf_hold_tag ($post)
 {
     global $health_check;
+    global $protocol_name;
 
     $tag["<<IPADDRESS>>"]          = escape_html($post["ipaddress"]);
     $tag["<<PORT>>"]               = escape_html($post["port"]);
+    $tag["<<PROTOCOL>>"]           = escape_html($post["protocol"]);
+    $tag["<<PROTOCOL_NAME>>"]      = escape_html($protocol_name[$post["protocol"]]);
     $tag["<<RSIPADDRESS>>"]        = escape_html($post["rs_ipaddress"]);
     $tag["<<RSPORT>>"]             = escape_html($post["rs_port"]);
     $tag["<<WEIGHT>>"]             = escape_html($post["weighting"]);
@@ -260,6 +266,8 @@ function rsconf_hold_tag ($post)
 /***********************************************************
  * 
  **********************************************************/
+$protocol_name = array("tcp", "udp");
+
 /* ե롢ִեɹåå */
 $ret = init();
 if ($ret === FALSE) {
@@ -306,7 +314,7 @@ $reload_result = "";
 if (isset($_POST["update"])) {
     if (rsconf_check_form($_POST)) {
 
-        $vsiport    = $_POST["ipaddress"]."_".$_POST["port"];
+        $vsiport    = $_POST["ipaddress"]."_".$_POST["port"]."_".$_POST["protocol"];
         $rsiport    = $_POST["rs_ipaddress"]."_".$_POST["rs_port"];
 
         $lock_fh = lock_file();
@@ -335,7 +343,8 @@ if (isset($_POST["update"])) {
             $sesskey = $_POST["sk"];
             $msg = "ꥢ륵 ".$_POST["rs_ipaddress"]." ".$_POST["rs_port"]." 򹹿ޤ";
             $post = array("ipaddress" => $_POST["ipaddress"],
-                          "port"      => $_POST["port"]);
+                          "port"      => $_POST["port"],
+                          "protocol"  => $_POST["protocol"]);
             iluka_location("rslist.php", $msg, $post);
             exit(0);
         }
@@ -347,6 +356,7 @@ if (isset($_POST["update"])) {
     $msg = ""; 
     $post = array("ipaddress"   => $_POST["ipaddress"],
                   "port"        => $_POST["port"],
+                  "protocol"    => $_POST["protocol"],
                   "rs_ipaddress" => $_POST["rs_ipaddress"],
                   "rs_port"      => $_POST["rs_port"]);
     iluka_location("rslist.php",$msg, $post);
