@@ -89,16 +89,16 @@ function edit_rslist ($file, $iport, $rsiport, $act, &$data)
     }
 
 
-    /* ̵ͭ */
+    /* ͭ->̵ */
     if ($act === 'disable') {
-        $err_msg = sprintf($msgarr['28076'][SCREEN_MSG], $rsiport);
+        $err_msg = sprintf($msgarr['28076'][SCREEN_MSG], dirname2msg($rsiport));
 
-    /* ̵ͭ */
+    /* ̵->ͭ */
     } elseif ($act === 'enable') {
-        $err_msg = sprintf($msgarr['28077'][SCREEN_MSG], $rsiport);
+        $err_msg = sprintf($msgarr['28077'][SCREEN_MSG], dirname2msg($rsiport));
     } else {
         /* Ƥκ */
-        $err_msg = sprintf($msgarr['28078'][SCREEN_MSG], $rsiport);
+        $err_msg = sprintf($msgarr['28078'][SCREEN_MSG], dirname2msg($rsiport));
 
         /* ե뤬Ĥä */
         if ($msgs !== "") {
@@ -211,9 +211,34 @@ function delete_reals($iport, $rsiport)
     return "";
 }
 
+/**********************************************************
+ * dirname2msg
+ *
+ * ꥢ륵ǥ쥯ȥ̾ɽѥåѴ
+ *
+ * []
+ *        $dirname         ꥢ륵ǥ쥯ȥ̾
+ * [֤]
+ *        $msgs            ɽѥå
+ **********************************************************/
+function dirname2msg($dirname)
+{
+    global $protocol_name;
+
+    $parts = explode("_", $dirname, 2);
+    if (count($parts) !== 2) {
+        return $dirname;
+    }
+
+    return $parts[0] . " " . $parts[1];
+}
+
+
 /***********************************************************
  * 
  **********************************************************/
+$protocol_name = array("tcp", "udp");
+
 /* ե롢ִեɹåå */
 $ret = init();
 if ($ret === FALSE) {
@@ -235,11 +260,13 @@ if ($result === 1) {
 $vsconffile = $web_conf["iluka"]["keepalivedbasedir"]."virtual_server.conf";
 $info_file = "../../../../tmpl/iluka_lb_rslist_info.tmpl";
 
-$iport      = $_POST["ipaddress"]."_".$_POST["port"];
+$iport      = $_POST["ipaddress"]."_".$_POST["port"]."_".$_POST["protocol"];
 $rsconffile = $web_conf["iluka"]["keepalivedbasedir"]."virtual_server/".$iport."/real_server.conf";
 
 $tag["<<IPADDRESS>>"]   = $_POST["ipaddress"];
 $tag["<<PORT>>"]        = $_POST["port"];
+$tag["<<PROTOCOL>>"]    = $_POST["protocol"];
+$tag["<<PROTOCOL_NAME>>"] = $protocol_name[$_POST["protocol"]];
 $all = "";
 
 
@@ -251,7 +278,7 @@ if (isset($_POST["rs_act_class"])) {
     $msgport = $_POST["rs_port"];
     $rsiport = $msgadr.'_'.$msgport;
 
-    /* ̵ͭ */
+    /* ͭ->̵ */
     if ($_POST["rs_act_class"] == "disable") {
         $act = 'disable';
 
@@ -274,7 +301,7 @@ if (isset($_POST["rs_act_class"])) {
             exit(0);
         }
 
-    /* ̵ͭ */
+    /* ̵->ͭ */
     } elseif ($_POST["rs_act_class"] == "enable") {
         $act = 'enable';
 
