@@ -61,7 +61,7 @@ function make_filedir ($tmplfile, $post)
     global $web_conf;
 
     $dirs   = $web_conf["iluka"]["keepalivedbasedir"]."virtual_server/";
-    $iport  = $post["ipaddress"]."_".$post["port"];
+    $iport  = $post["ipaddress"]."_".$post["port"]."_".$post["protocol"];
     $vsfile = "$dirs$iport".'.conf';
     $vsdir  = "$dirs$iport";
     $rslist  = "$dirs$iport"."/real_server.conf";
@@ -88,6 +88,8 @@ function make_filedir ($tmplfile, $post)
     
     $tag["<<IP_ADDRESS>>"] = $post["ipaddress"];
     $tag["<<PORT>>"] = $post["port"];
+    $tag["<<PROTOCOL_NUMBER>>"] = $post["protocol"];
+
     $tag["<<DELAY_LOOP>>"] = 'delay_loop '.$post["delay_loop"];
     $tag["<<LB_ALGO>>"] = 'lb_algo '.$lb_algo[$post["lb_algo"]];
     $tag["<<LB_KIND>>"] = 'lb_kind '.$lb_kind[$post["lb_kind"]];
@@ -189,8 +191,9 @@ function add_vslist ($post, $file, $tmplfile, &$data)
 
     /* $dataɲ */
     $push["able"] = 'disable';
-    $push["ipaddress"] = $_POST["ipaddress"];
-    $push["port"] = $_POST["port"];
+    $push["ipaddress"] = $post["ipaddress"];
+    $push["port"] = $post["port"];
+    $push["protocol"] = $post["protocol"];
     $data[] = $push;
 
     $result = write_vslist($file, $data);
@@ -275,6 +278,8 @@ $add_result = "";
 /*  */
 $tag["<<IPADDRESS>>"]              = "";
 $tag["<<PORT>>"]                   = "";
+$tag["<<PROTOCOL_NUMBER>>"]        = "";
+$tag["<<PROTOCOL>>"]               = "";
 $tag["<<DELAY_LOOP>>"]             = "";
 $tag["<<PERSISTENCE_TIMEOUT>>"]    = "";
 $tag["<<VIRTUALHOST>>"]            = "";
@@ -294,8 +299,9 @@ $kind_list = array('ͥåȥɥ쥹 (NAT)',
                    '쥯ȥ롼ƥ (DR)',
                    'ȥͥ (TUN)');
 
-$protocol_list = array('TCP',
-                       'UDP');
+$protocol_list = array('TCP', 'UDP');
+
+$protocol_name = array('tcp', 'udp');
 
 /***********************************************************
  * main
@@ -324,7 +330,9 @@ if (isset($_POST["update"])) {
         }
   
         if ($add_result === TRUE) {
-            $msg = "С륵 ".$_POST["ipaddress"]." ".$_POST["port"]." ɲäޤ";
+            $msg = "С륵 " . $_POST["ipaddress"] . " " .
+                   $_POST["port"] .  "/" . $protocol_name[$_POST["protocol"]] .
+                   " ɲäޤ";
             dgp_location("index.php", $msg);
             exit(0);
         }
