@@ -57,8 +57,8 @@ $kind_list = array('ͥåȥɥ쥹 (NAT)',
                    '쥯ȥ롼ƥ (DR)',
                    'ȥͥ (TUN)');
 
-$protocol_list = array('TCP',
-	               'UDP');
+$protocol_list = array('TCP', 'UDP');
+$protocol_name = array('tcp', 'udp');
 
 /* եѤʬ르ꥺž */
 $check_lb_algo = array("rr", "wrr", "lc", "wlc", "lblc", "sh", "dh");
@@ -292,6 +292,8 @@ function change_conffile ($tmplfile, $post, $iport)
 
     $tag["<<IP_ADDRESS>>"]          = $post["ipaddress"];
     $tag["<<PORT>>"]                = $post["port"];
+    $tag["<<PROTOCOL_NUMBER>>"]     = $post["protocol"];
+
     $tag["<<DELAY_LOOP>>"]          = "delay_loop ".$post["delay_loop"];
     $tag["<<LB_ALGO>>"]             = "lb_algo ".$check_lb_algo[$post["lb_algo"]];
     $tag["<<LB_KIND>>"]             = "lb_kind ".$check_lb_kind[$post["lb_kind"]];
@@ -355,7 +357,7 @@ function change_tag_vsconf (&$data)
 {
     global $algo_list;
     global $kind_list;
-    global $protocol_list;
+    global $protocol_name;
 
     $tag["<<IPADDRESS>>"]              = escape_html($data["ipaddress"]);
     $tag["<<PORT>>"]                   = escape_html($data["port"]);
@@ -384,15 +386,18 @@ function change_tag_vsconf (&$data)
         }
     }
 
-    $tag["<<PROTOCOL>>"] = "";
-    foreach($protocol_list as $key => $value) {
-        if ($data["protocol"] == $key) {
-            $tag["<<PROTOCOL>>"] .= "<option value=\"$key\" selected>".$value."</option>\n";
-        } else {
-            $tag["<<PROTOCOL>>"] .= "<option value=\"$key\">".$value."</option>\n";
-        }
+    switch ($data["protocol"]) {
+        case 0:
+        case 1:
+            $tag["<<PROTOCOL_NAME>>"] = $protocol_name[$data["protocol"]];
+            break;
+        default:
+            $tag["<<PROTOCOL_NAME>>"] = "unknown";
+            break;
     }
 
+    $tag["<<PROTOCOL>>"] = $data["protocol"];
+
     return $tag;
 }
 
@@ -424,8 +429,9 @@ $change_result = "";
 /* ܼɽIPɥ쥹ڤӥݡֹ */
 $data["ipaddress"] = $_POST["ipaddress"];
 $data["port"]      = $_POST["port"];
+$data["protocol"]  = $_POST["protocol"];
 
-$iport      = $data["ipaddress"]."_".$data["port"];
+$iport      = $data["ipaddress"]."_".$data["port"]."_".$data["protocol"];
 $vsconfpass = $web_conf["iluka"]["keepalivedbasedir"].'virtual_server/'.$iport.'.conf';
 
 /***********************************************************
@@ -456,7 +462,9 @@ if (isset($_POST["update"])) {
         }
 
         if ($change_result === TRUE) {
-            $msg = "С륵 ".$_POST["ipaddress"]." ".$_POST["port"]." 򹹿ޤ";
+            $msg = "С륵 " . $_POST["ipaddress"] . "  " .
+                   $_POST["port"] . "/" . $protocol_name[$_POST["protocol"]] .
+                   " 򹹿ޤ";
             dgp_location("index.php", $msg);
             exit(0);
         }
